<AWT Dev> [8] Request for review: 8020851 java.awt.event.WindowEvent spec should state that WINDOW_CLOSED event may not be delivered under certain circumstances

Sergey Bylokhov sergey.bylokhov at oracle.com
Tue Sep 17 02:43:59 PDT 2013


Hello,
Please review the fix for jdk 8.
Documentation for WINDOW_CLOSED was updated, ccc request will be filed after review.
Bug: https://bugs.openjdk.java.net/browse/JDK-8020851

Patch is small so I place it here:

--- old/src/share/classes/java/awt/event/WindowEvent.java    2013-09-17 13:28:01.011335900 +0400
+++ new/src/share/classes/java/awt/event/WindowEvent.java    2013-09-17 13:28:00.613326500 +0400
@@ -25,6 +25,7 @@
+import java.awt.Component;
 import sun.awt.AppContext;
@@ -79,8 +80,10 @@
     /**
      * The window closed event. This event is delivered after
      * the window has been closed as the result of a call to dispose.
      */
     @Native public static final int WINDOW_CLOSED       = 2 + WINDOW_FIRST;
 
@@ -79,8 +80,10 @@
     /**
-     * The window closed event. This event is delivered after
-     * the window has been closed as the result of a call to dispose.
+     * The window closed event. This event is delivered after the displayable
+     * window has been closed as the result of a call to dispose.
+     * @see Component#isDisplayable
+     * @see Window#dispose
      */
     @Native public static final int WINDOW_CLOSED       = 2 + WINDOW_FIRST;

-- 
Best regards, Sergey.


More information about the awt-dev mailing list